Module error

Module error 

Unified error and result types for the Oxide Kernel.

Enums

KernelError
All errors that can be produced by the kernel and its subsystems.

Type Aliases

Result
Convenient Result alias used throughout the kernel.