Unified error and result types for the Oxide Kernel.
Enums
- Kernel
Error - All errors that can be produced by the kernel and its subsystems.
Type Aliases
- Result
- Convenient
Resultalias used throughout the kernel.
Unified error and result types for the Oxide Kernel.
Result alias used throughout the kernel.